package info.msxlaunchers.openmsx.common;

import info.msxlaunchers.openmsx.common.IOUtils;

import java.io.Closeable;
import java.io.IOException;
import java.util.zip.ZipFile;

import org.junit.Test;
import org.mockito.Mockito;

import static org.mockito.Mockito.mock;

public class IOUtilsTest
{
	@Test
	public void testForceCloseCloseable()
	{
		Closeable closeable = mock( Closeable.class );

		IOUtils.forceClose( closeable );
	}

	@Test
	public void testForceCloseCloseableForNull()
	{
		Closeable closeable = null;

		//test that nothing happens
		IOUtils.forceClose( closeable );
	}

	@Test
	public void testForceCloseCloseableWithException() throws IOException
	{
		Closeable closeable = mock( Closeable.class );
		Mockito.doThrow( new IOException() ).when( closeable ).close();

		//test that exception is swallowed
		IOUtils.forceClose( closeable );
	}

	@Test
	public void testForceCloseZipFile()
	{
		ZipFile zipFile = mock( ZipFile.class );

		IOUtils.forceClose( zipFile );
	}

	@Test
	public void testForceCloseZipFileForNull()
	{
		ZipFile zipFile = null;

		//test that nothing happens
		IOUtils.forceClose( zipFile );
	}

	@Test
	public void testForceCloseZipFileWithException() throws IOException
	{
		ZipFile zipFile = mock( ZipFile.class );
		Mockito.doThrow( new IOException() ).when( zipFile ).close();

		//test that exception is swallowed
		IOUtils.forceClose( zipFile );
	}
}
