/*
 * Copyright 2013 Sam Elsharif
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package info.msxlaunchers.openmsx.game.repository.processor;

import info.msxlaunchers.openmsx.game.RepositoryGame;

import java.io.IOException;
import java.util.Map;
import java.util.Set;

import javax.xml.parsers.ParserConfigurationException;
import javax.xml.parsers.SAXParser;
import javax.xml.parsers.SAXParserFactory;

import org.xml.sax.SAXException;
import org.xml.sax.helpers.DefaultHandler;

/**
 * SAX parser implementation for <code>XMLProcessor</code>
 * 
 * @since v1.0
 * @author Sam Elsharif
 *
 */
final class SAXXMLProcessor implements XMLProcessor
{
	/* (non-Javadoc)
	 * @see info.msxlaunchers.openmsx.game.repository.processor.XMLProcessor#getRepositoryInfo(java.lang.String)
	 */
	@Override
	public Map<String,RepositoryGame> getRepositoryInfo( String xmlFile ) throws IOException
	{
		RepositoryInfoParseHandler handler = new RepositoryInfoParseHandler();

		parse( xmlFile, handler );

		return handler.getRepositoryInfo();
	}

	/* (non-Javadoc)
	 * @see info.msxlaunchers.openmsx.game.repository.processor.XMLProcessor#getOtherDumpCodes(java.lang.String, java.lang.String)
	 */
	@Override
	public Set<String> getOtherDumpCodes( String xmlFile, String code ) throws IOException
	{
		OtherDumpCodesParseHandler handler = new OtherDumpCodesParseHandler( code );

		parse( xmlFile, handler );
		
		return handler.getOtherDumpCodes();
	}

	/* (non-Javadoc)
	 * @see info.msxlaunchers.openmsx.game.repository.processor.XMLProcessor#getGameInfo(java.lang.String, java.lang.String)
	 */
	@Override
	public RepositoryGame getGameInfo( String xmlFile, String code ) throws IOException
	{
		GameInfoParseHandler handler = new GameInfoParseHandler( code );

		parse( xmlFile, handler );

		return handler.getGameInfo();
	}

	private void parse( String xmlFile, DefaultHandler handler ) throws IOException
	{
		SAXParserFactory spfac = SAXParserFactory.newInstance();

		try
        {
			SAXParser parser = spfac.newSAXParser();
			parser.parse( xmlFile, handler );
        }
		catch( StopSAXParsingException e )
		{
			//this exception means that parsing was stopped deliberately (e.g. data was found)
		}
        catch( ParserConfigurationException e )
        {
        	throw new IOException();
        }
        catch( SAXException e )
        {
        	throw new IOException();
        }
	}
}
