/*
 * Copyright 2013 Sam Elsharif
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package info.msxlaunchers.openmsx.launcher.data.global;

import info.msxlaunchers.openmsx.common.Utils;
import info.msxlaunchers.openmsx.launcher.data.global.constants.Language;

/**
 * Class to hold global settings for the application such as path to openMSX, path to openMSX's machines directory,
 * path to screenshots, default database to show when application first starts up and display language
 * 
 * @since v1.0
 * @author Sam Elsharif
 *
 */
public final class Settings
{
	private final String openMSXFullPath;
	private final String openMSXMachinesFullPath;
	private final String screenshotsFullPath;
	private final String defaultDatabase;
	private final Language language;

	public Settings( String openMSXFullPath,
			String openMSXMachinesFullPath,
			String screenshotsFullPath,
			String defaultDatabase,
			Language language )
	{
		this.openMSXFullPath = openMSXFullPath;
		this.openMSXMachinesFullPath = openMSXMachinesFullPath;
		this.screenshotsFullPath = screenshotsFullPath;
		this.defaultDatabase = defaultDatabase;
		this.language = language;
	}

	@Override
	public int hashCode() {
		final int prime = 31;
		int result = 1;
		result = prime * result
				+ ((defaultDatabase == null) ? 0 : defaultDatabase.hashCode());
		result = prime * result
				+ ((language == null) ? 0 : language.hashCode());
		result = prime * result
				+ ((openMSXFullPath == null) ? 0 : openMSXFullPath.hashCode());
		result = prime
				* result
				+ ((openMSXMachinesFullPath == null) ? 0
						: openMSXMachinesFullPath.hashCode());
		result = prime
				* result
				+ ((screenshotsFullPath == null) ? 0 : screenshotsFullPath
						.hashCode());
		return result;
	}

	@Override
	public boolean equals( Object obj )
	{
		if( this == obj )
		{
			return true;
		}
		if( obj == null )
		{
			return false;
		}
		if( getClass() != obj.getClass() )
		{
			return false;
		}
		Settings other = (Settings) obj;
		if( defaultDatabase == null )
		{
			if( other.defaultDatabase != null )
			{
				return false;
			}
		}
		else if( !defaultDatabase.equals( other.defaultDatabase ) )
		{
			return false;
		}
		if( language != other.language )
		{
			return false;
		}
		if( openMSXFullPath == null )
		{
			if( other.openMSXFullPath != null )
			{
				return false;
			}
		}
		else if( !openMSXFullPath.equals( other.openMSXFullPath ) )
		{
			return false;
		}
		if( openMSXMachinesFullPath == null )
		{
			if( other.openMSXMachinesFullPath != null )
			{
				return false;
			}
		}
		else if( !openMSXMachinesFullPath.equals(other.openMSXMachinesFullPath ) )
		{
			return false;
		}
		if( screenshotsFullPath == null )
		{
			if( other.screenshotsFullPath != null )
			{
				return false;
			}
		}
		else if( !screenshotsFullPath.equals( other.screenshotsFullPath ) )
		{
			return false;
		}
		return true;
	}

	//--------
	// Getters
	//--------
	public String getOpenMSXFullPath()
	{
		if( Utils.isEmpty( openMSXFullPath ) )
		{
			return null;
		}
		else
		{
			return openMSXFullPath;
		}
	}

	public String getOpenMSXMachinesFullPath()
	{
		if( Utils.isEmpty( openMSXMachinesFullPath ) )
		{
			return null;
		}
		else
		{
			return openMSXMachinesFullPath;
		}
	}

	public String getScreenshotsFullPath()
	{
		if( Utils.isEmpty( screenshotsFullPath ) )
		{
			return null;
		}
		else
		{
			return screenshotsFullPath;
		}
	}

	public String getDefaultDatabase()
	{
		if( Utils.isEmpty( defaultDatabase ) )
		{
			return null;
		}
		else
		{
			return defaultDatabase;
		}
	}

	public Language getLanguage()
	{
		return language;
	}
}
