/*
 * Copyright 2013 Sam Elsharif
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package info.msxlaunchers.openmsx.launcher.starter;

import info.msxlaunchers.openmsx.common.Utils;
import info.msxlaunchers.openmsx.launcher.data.game.Game;
import info.msxlaunchers.openmsx.launcher.data.global.Settings;
import info.msxlaunchers.platform.ArgumentsBuilder;

import java.io.File;
import java.util.List;

import com.google.inject.Inject;

/**
 * Implementation of <code>StarterPlatformArguments</code> for Windows
 * 
 * @since v1.0
 * @author Sam Elsharif
 *
 */
class WindowsStarterArguments implements StarterPlatformArguments
{
	private final ArgumentsBuilder argumentsBuilder;

	@Inject
	WindowsStarterArguments( ArgumentsBuilder argumentsBuilder )
	{
		this.argumentsBuilder = argumentsBuilder;
	}

	/* (non-Javadoc)
	 * @see info.msxlaunchers.openmsx.launcher.starter.StarterPlatformArguments#getArguments(info.msxlaunchers.openmsx.launcher.data.global.Settings, info.msxlaunchers.openmsx.launcher.data.game.Game)
	 */
	@Override
	public List<String> getArguments( Settings settings, Game game )
	{
		File openMSXDirectory = new File( settings.getOpenMSXFullPath() );
		File fullpath = new File( openMSXDirectory, "openmsx.exe" );

		argumentsBuilder.append( fullpath.getAbsolutePath() );

		String script = game.getTclScript();

		if( Utils.isEmpty( script ) )
		{
			//if no script is used then look at the other arguments
			argumentsBuilder.appendIfValueDefined( "-carta", game.getRomA() );
			argumentsBuilder.appendIfValueDefined( "-cartb", game.getRomB() );
			argumentsBuilder.appendIfValueDefined( "-ext", game.getExtensionRom() );
			argumentsBuilder.appendIfValueDefined( "-diska", game.getDiskA() );
			argumentsBuilder.appendIfValueDefined( "-diskb", game.getDiskB() );
			argumentsBuilder.appendIfValueDefined( "-cassetteplayer", game.getTape() );
			argumentsBuilder.appendIfValueDefined( "-hda", game.getHarddisk() );
			argumentsBuilder.appendIfValueDefined( "-machine", game.getMachine() );
			argumentsBuilder.appendIfValueDefined( "-laserdisc", game.getLaserdisc() );
		}
		else
		{
			//script in this case overrides all other arguments
			argumentsBuilder.appendIfValueDefined( "-script", script );
		}

		return argumentsBuilder.getArgumentList();
	}
}
